Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(8560)

Unified Diff: chrome/browser/webdata/web_database.h

Issue 1789001: AutoFill crash in CreditCard::SetInfo(). (Closed)
Patch Set: Virtual back to original. Created 10 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/autofill/autofill_type_unittest.cc ('k') | chrome/browser/webdata/web_database.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/webdata/web_database.h
diff --git a/chrome/browser/webdata/web_database.h b/chrome/browser/webdata/web_database.h
index 07f30a9469c8604c6b3e25b7bb9c65c944b1939a..1883730915038640690c2174ffe4327161c5d640 100644
--- a/chrome/browser/webdata/web_database.h
+++ b/chrome/browser/webdata/web_database.h
@@ -237,24 +237,26 @@ class WebDatabase {
virtual bool GetAutoFillProfiles(std::vector<AutoFillProfile*>* profiles);
// Records a single credit card in the credit_cards table.
- bool AddCreditCard(const CreditCard& creditcard);
+ bool AddCreditCard(const CreditCard& credit_card);
- // Updates the database values for the specified profile.
- bool UpdateCreditCard(const CreditCard& profile);
+ // Updates the database values for the specified credit card.
+ bool UpdateCreditCard(const CreditCard& credit_card);
- // Removes a row from the autofill_profiles table. |profile_id| is the
- // unique ID of the profile to remove.
- bool RemoveCreditCard(int profile_id);
+ // Removes a row from the credit_cards table. |credit_card_id| is the
+ // unique ID of the credit card to remove.
+ bool RemoveCreditCard(int credit_card_id);
- // Retrieves a profile with label |label|. The caller owns |profile|.
+ // Retrieves a credit card with label |label|. The caller owns
+ // |credit_card_id|.
bool GetCreditCardForLabel(const string16& label,
- CreditCard** profile);
+ CreditCard** credit_card);
- // Retrieves credit card for a card with unique id |card_id|.
- bool GetCreditCardForID(int card_id, CreditCard** card);
+ // Retrieves credit card for a card with unique id |credit_card_id|.
+ bool GetCreditCardForID(int credit_card_id, CreditCard** credit_card);
- // Retrieves all profiles in the database. Caller owns the returned profiles.
- virtual bool GetCreditCards(std::vector<CreditCard*>* profiles);
+ // Retrieves all credit cards in the database. Caller owns the returned
+ // credit cards.
+ virtual bool GetCreditCards(std::vector<CreditCard*>* credit_cards);
//////////////////////////////////////////////////////////////////////////////
//
« no previous file with comments | « chrome/browser/autofill/autofill_type_unittest.cc ('k') | chrome/browser/webdata/web_database.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698